# <img src="docs/img/looper_logo.svg" alt="looper logo" height="70">

![Run pytests](https://github.com/pepkit/looper/workflows/Run%20pytests/badge.svg)
[![PEP compatible](http://pepkit.github.io/img/PEP-compatible-green.svg)](http://pepkit.github.io)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)


`Looper` is a pipeline submission engine. The typical use case is to run a bioinformatics pipeline across many different input samples. Instructions are in the [documentation](http://looper.databio.org/).
